Class: Aws::LicenseManagerLinuxSubscriptions::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::LicenseManagerLinuxSubscriptions::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-licensemanagerlinuxsubscriptions/client.rb,
sig/client.rbs
Overview
An API client for LicenseManagerLinuxSubscriptions. To construct a client, you need to configure a :region and :credentials.
client = Aws::LicenseManagerLinuxSubscriptions::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _DeregisterSubscriptionProviderResponseSuccess, _GetRegisteredSubscriptionProviderResponseSuccess, _GetServiceSettingsResponseSuccess, _ListLinuxSubscriptionInstancesResponseSuccess, _ListLinuxSubscriptionsResponseSuccess, _ListRegisteredSubscriptionProvidersResponseSuccess, _ListTagsForResourceResponseSuccess, _RegisterSubscriptionProviderResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateServiceSettingsResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#deregister_subscription_provider(params = {}) ⇒ Struct
Remove a third-party subscription provider from the Bring Your Own License (BYOL) subscriptions registered to your account.
-
#get_registered_subscription_provider(params = {}) ⇒ Types::GetRegisteredSubscriptionProviderResponse
Get details for a Bring Your Own License (BYOL) subscription that's registered to your account.
-
#get_service_settings(params = {}) ⇒ Types::GetServiceSettingsResponse
Lists the Linux subscriptions service settings for your account.
-
#list_linux_subscription_instances(params = {}) ⇒ Types::ListLinuxSubscriptionInstancesResponse
Lists the running Amazon EC2 instances that were discovered with commercial Linux subscriptions.
-
#list_linux_subscriptions(params = {}) ⇒ Types::ListLinuxSubscriptionsResponse
Lists the Linux subscriptions that have been discovered.
-
#list_registered_subscription_providers(params = {}) ⇒ Types::ListRegisteredSubscriptionProvidersResponse
List Bring Your Own License (BYOL) subscription registration resources for your account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List the metadata tags that are assigned to the specified Amazon Web Services resource.
-
#register_subscription_provider(params = {}) ⇒ Types::RegisterSubscriptionProviderResponse
Register the supported third-party subscription provider for your Bring Your Own License (BYOL) subscription.
-
#tag_resource(params = {}) ⇒ Struct
Add metadata tags to the specified Amazon Web Services resource.
-
#untag_resource(params = {}) ⇒ Struct
Remove one or more metadata tag from the specified Amazon Web Services resource.
-
#update_service_settings(params = {}) ⇒ Types::UpdateServiceSettingsResponse
Updates the service settings for Linux subscriptions.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-licensemanagerlinuxsubscriptions/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1010 1011 1012 |
# File 'lib/aws-sdk-licensemanagerlinuxsubscriptions/client.rb', line 1010 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1013 1014 1015 |
# File 'lib/aws-sdk-licensemanagerlinuxsubscriptions/client.rb', line 1013 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 |
# File 'lib/aws-sdk-licensemanagerlinuxsubscriptions/client.rb', line 983 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::LicenseManagerLinuxSubscriptions') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-licensemanagerlinuxsubscriptions' context[:gem_version] = '1.47.0' Seahorse::Client::Request.new(handlers, context) end |
#deregister_subscription_provider(params = {}) ⇒ Struct
Remove a third-party subscription provider from the Bring Your Own License (BYOL) subscriptions registered to your account.
85 |
# File 'sig/client.rbs', line 85
def deregister_subscription_provider: (
|
#get_registered_subscription_provider(params = {}) ⇒ Types::GetRegisteredSubscriptionProviderResponse
Get details for a Bring Your Own License (BYOL) subscription that's registered to your account.
100 |
# File 'sig/client.rbs', line 100
def get_registered_subscription_provider: (
|
#get_service_settings(params = {}) ⇒ Types::GetServiceSettingsResponse
Lists the Linux subscriptions service settings for your account.
114 |
# File 'sig/client.rbs', line 114
def get_service_settings: (
|
#list_linux_subscription_instances(params = {}) ⇒ Types::ListLinuxSubscriptionInstancesResponse
Lists the running Amazon EC2 instances that were discovered with commercial Linux subscriptions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
124 |
# File 'sig/client.rbs', line 124
def list_linux_subscription_instances: (
|
#list_linux_subscriptions(params = {}) ⇒ Types::ListLinuxSubscriptionsResponse
Lists the Linux subscriptions that have been discovered. If you have linked your organization, the returned results will include data aggregated across your accounts in Organizations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
143 |
# File 'sig/client.rbs', line 143
def list_linux_subscriptions: (
|
#list_registered_subscription_providers(params = {}) ⇒ Types::ListRegisteredSubscriptionProvidersResponse
List Bring Your Own License (BYOL) subscription registration resources for your account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
162 |
# File 'sig/client.rbs', line 162
def list_registered_subscription_providers: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
List the metadata tags that are assigned to the specified Amazon Web Services resource.
174 |
# File 'sig/client.rbs', line 174
def list_tags_for_resource: (
|
#register_subscription_provider(params = {}) ⇒ Types::RegisterSubscriptionProviderResponse
Register the supported third-party subscription provider for your Bring Your Own License (BYOL) subscription.
186 |
# File 'sig/client.rbs', line 186
def register_subscription_provider: (
|
#tag_resource(params = {}) ⇒ Struct
Add metadata tags to the specified Amazon Web Services resource.
197 |
# File 'sig/client.rbs', line 197
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Remove one or more metadata tag from the specified Amazon Web Services resource.
207 |
# File 'sig/client.rbs', line 207
def untag_resource: (
|
#update_service_settings(params = {}) ⇒ Types::UpdateServiceSettingsResponse
Updates the service settings for Linux subscriptions.
222 |
# File 'sig/client.rbs', line 222
def update_service_settings: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1003 1004 1005 |
# File 'lib/aws-sdk-licensemanagerlinuxsubscriptions/client.rb', line 1003 def waiter_names [] end |