Class: Aws::LicenseManagerLinuxSubscriptions::Types::ListLinuxSubscriptionInstancesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::LicenseManagerLinuxSubscriptions::Types::ListLinuxSubscriptionInstancesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-licensemanagerlinuxsubscriptions/types.rb
Overview
NextToken length limit is half of ddb accepted limit. Increase this limit if parameters in request increases.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
An array of structures that you can use to filter the results to those that match one or more sets of key-value pairs that you specify.
-
#max_results ⇒ Integer
Maximum number of results to return in a single call.
-
#next_token ⇒ String
Token for the next set of results.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
An array of structures that you can use to filter the results to those that match one or more sets of key-value pairs that you specify. For example, you can filter by the name of AmiID with an optional operator to see subscriptions that match, partially match, or don’t match a certain Amazon Machine Image (AMI) ID.
The valid names for this filter are:
-
AmiID -
InstanceID -
AccountID -
Status -
Region -
UsageOperation -
ProductCode -
InstanceType
The valid Operators for this filter are:
-
contains -
equals -
Notequal
232 233 234 235 236 237 238 |
# File 'lib/aws-sdk-licensemanagerlinuxsubscriptions/types.rb', line 232 class ListLinuxSubscriptionInstancesRequest < Struct.new( :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Maximum number of results to return in a single call.
232 233 234 235 236 237 238 |
# File 'lib/aws-sdk-licensemanagerlinuxsubscriptions/types.rb', line 232 class ListLinuxSubscriptionInstancesRequest < Struct.new( :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Token for the next set of results.
232 233 234 235 236 237 238 |
# File 'lib/aws-sdk-licensemanagerlinuxsubscriptions/types.rb', line 232 class ListLinuxSubscriptionInstancesRequest < Struct.new( :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |