Class: Aws::LicenseManagerLinuxSubscriptions::Types::TagResourceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-licensemanagerlinuxsubscriptions/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:tags]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arnString

The Amazon Resource Name (ARN) of the Amazon Web Services resource to which to add the specified metadata tags.

Returns:

  • (String)


657
658
659
660
661
662
# File 'lib/aws-sdk-licensemanagerlinuxsubscriptions/types.rb', line 657

class TagResourceRequest < Struct.new(
  :resource_arn,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end

#tagsHash<String,String>

The metadata tags to assign to the Amazon Web Services resource. Tags are formatted as key value pairs.

Returns:

  • (Hash<String,String>)


657
658
659
660
661
662
# File 'lib/aws-sdk-licensemanagerlinuxsubscriptions/types.rb', line 657

class TagResourceRequest < Struct.new(
  :resource_arn,
  :tags)
  SENSITIVE = [:tags]
  include Aws::Structure
end